import React, { useState, useEffect, useRef } from 'react';
import { Carousel, Spin, notification } from 'antd';
import { connect } from 'react-redux';
import { chunk } from 'lodash';
import classnames from 'classnames';
import SecurityLayout from '@/layouts/SecurityLayout';
import styles from './index.less';
import Panel from './Panel';
import { appService, cloudService } from '@/api'
import { actionCreators } from '@/containers/App/store';
import { defaultApp } from '@/micro';
import LoginAction from '../../../user/login/login';
import Cookies from 'js-cookie';
import { decode, encode } from 'js-base64';
import title from './images/title.png';

/**
 *  熊猫新产品引导页
 */

const pageSize = 6; 

const NewProducts = props => {
  const [products, setProducts] = useState([]);
  const [loading, setLoading] = useState(false);
  const ref = useRef();


  // 获取卡片数据
  useEffect(() => {
    setLoading(true);
    cloudService.getAccountPageList({
      pageIndex: 1,
      pageSize: 100,
      sortFields: '排序',
      direction: 'desc',
      accountName: '演示_熊猫新产品',
      // info: searchInfo,
      // queryWhere:
      //   " and (登录时间 >= '" + stime + "' and 登录时间 <= '" + etime + "')",
      ignoreSite: true,
    }).then(res => {
      setLoading(false);
      const configData = JSON.parse(res.data.jsonData || '[]');
      const configMap = configData.reduce((pre, item, index) => {
        item['排序'] = index
        if(item.site && item['是否显示'] === '是') {
          pre[item.site] = item;
        }
        return pre;
      }, {});
      const Groups = props.global?.userInfo?.Groups ?? [];
      const data = Groups
        .filter(item => item.industry === '熊猫新产品' && configMap[item.site])
        .map(item => ({ ...item, config: configMap[item.site] }));
      data.sort((a,b) => a.config['排序'] - b.config['排序']);
      setProducts(chunk(data, pageSize));
    }).catch(err => {
      setLoading(false);
      notification.error({ message: '提示', duration: 3, description: '获取产品信息错误' })
    })
  }, []);


  // 卡片点击事件
  const handleClick = (e, data) => {
    setLoading(true);
    appService
      .getUserInfo({
        token: props.global.token,
        subOID: 'subOID',
        site: data.site,
        ignoreSite: true,
      })
      .then(res => {
        // 重置一些环境配置
        const config = { ...props.global };
        config.uiwidgets = [];
        config.widgets = [];
        config.allWidgets = [];
        config.userInfo = res;
        props.updateConfig && props.updateConfig(config);

        // 默认有个上次记住的登入企业，存在印象。这里把cookie和localStorage中的都重新设置一下
        const date = new Date();
        date.setTime(date.getTime() + 24 * 60 * 60 * 1000);
        const encodeSite = encode(encodeURIComponent(data.site));
        localStorage.setItem('loginSite', JSON.stringify({[config.token]: data.site}))
        Cookies.set('site', encodeSite, {
          expires: date,
          path: '/',
        });

        const loginAction = new LoginAction({...props, global: config});
        // props.instance && props.instance.updateConfig(config);
        loginAction && loginAction.getUserInfoAndConfig('', true, '熊猫新产品');
      });
  };


  // toggleIndustry 事件
  useEffect(() => {
    // 借用引导页的触发逻辑进入系统
    const handleToggleIndustry = event => {
      setLoading(false);
      props.history.push(`/?client=${props.global.client}`);
      defaultApp();
      // window.share.event.emit('triggerMicro', props.global);
      props.updateCurrentIndex(0);
    };
    window.share.event.on('toggleIndustry', handleToggleIndustry);
    return () => {
      window.share.event.removeListener('toggleIndustry', handleToggleIndustry);
    };
  }, [window.share.event, props]);


  // 卡片左右切换
  const onPrev = e => ref.current && ref.current.prev();
  const onNext = e => ref.current && ref.current.next();


  return (
    <SecurityLayout>
      <div className={styles.newproducts}>
        <Spin spinning={loading}>
          <div className={styles.page}>
            <h1>
              <img className={styles['title-img']} src={title} alt="熊猫智慧水务新产品"/>
            </h1>
            <div className={styles.container}>
              <Carousel ref={ref}>
                { products.map((item, index) => <Panel key={index} products={item} pageIndex={index} pageSize={pageSize} onCardClick={handleClick}/>) }
              </Carousel>
              {
                products && products.length > 1 && (
                  <>
                    <div className={classnames(styles['cus-arrow'], styles['cus-arrow-prev'])} title="上一页" onClick={onPrev}></div>
                    <div className={classnames(styles['cus-arrow'], styles['cus-arrow-next'])} title="下一页" onClick={onNext}></div>
                  </>
                )
              }
            </div>
          </div>
        </Spin>
      </div>
    </SecurityLayout>
  );
};
const mapStateToProps = (state) => ({
  global: state.getIn(['global', 'globalConfig']),
});
const mapDispatchToProps = (dispatch) => ({
  updateConfig(config) {
    dispatch(actionCreators.getConfig(config));
  },
  updateCurrentIndex(index) {
    dispatch(actionCreators.updateCurrentIndex(index));
  },
});
export default connect(mapStateToProps, mapDispatchToProps)(NewProducts);